==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Offset</name>
    <message>
        <source>Distance:</source>
        <translation type="obsolete">Abstand:</translation>
    </message>
    <message>
        <source>1</source>
        <translation type="obsolete">1</translation>
    </message>
    <message>
        <source>Number:</source>
        <translation type="obsolete">Anzahl:</translation>
    </message>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">Linie, Bogen oder Kreis wählen</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translation type="obsolete">Para&amp;llele (mit Distanz)</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Versatz (mit Distanz)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Linie, Bogen, Kreis oder Ellipse versetzen</translation>
    </message>
    <message>
        <source>Offset line, arc, circle, ellipse or polyline</source>
        <translation type="vanished">Linie, Bogen, Kreis, Ellipse oder Polylinie versetzen</translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translation type="vanished">Parallele zu existierender Linie oder konzentrischer Bogen, Kreis</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Abstand:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Anzahl:</translation>
    </message>
    <message>
        <source>Choose line, arc, circle, ellipse or spline</source>
        <translation type="vanished">Linie, Bogen, Kreis oder Ellipse wählen</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Linie, Bogen, Kreis oder Ellipse wählen</translation>
    </message>
    <message>
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation>Radius kleiner als 0.0 nach %1 konzentrischen Kreis(en).</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation>Radius kleiner als 0.0 nach %1 konzentrischen Kreisbögen.</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Offset</name>
    <message>
        <source>Distance:</source>
        <translation type="obsolete">Abstand:</translation>
    </message>
    <message>
        <source>1</source>
        <translation type="obsolete">1</translation>
    </message>
    <message>
        <source>Number:</source>
        <translation type="obsolete">Anzahl:</translation>
    </message>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">Linie, Bogen oder Kreis wählen</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translation type="obsolete">Para&amp;llele (mit Distanz)</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Versatz (mit Distanz)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Linie, Bogen, Kreis oder Ellipse versetzen</translation>
    </message>
    <message>
        <source>Offset line, arc, circle, ellipse or polyline</source>
        <translation type="vanished">Linie, Bogen, Kreis, Ellipse oder Polylinie versetzen</translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translation type="vanished">Parallele zu existierender Linie oder konzentrischer Bogen, Kreis</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Abstand:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Anzahl:</translation>
    </message>
    <message>
        <source>Choose line, arc, circle, ellipse or spline</source>
        <translation type="vanished">Linie, Bogen, Kreis oder Ellipse wählen</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Linie, Bogen, Kreis oder Ellipse wählen</translation>
    </message>
    <message numerus="yes">
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %n concentric circle(s).</source>
        <translation>
            <numerusform>Radius kleiner als 0.0 nach einem konzentrischen Kreis.</numerusform>
            <numerusform>Radius kleiner als 0.0 nach %n konzentrischen Kreisen.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %n concentric arc(s).</source>
        <translation>
            <numerusform>Radius kleiner als 0.0 nach einem konzentrischen Kreisbogen.</numerusform>
            <numerusform>Radius kleiner als 0.0 nach %n konzentrischen Kreisbögen.</numerusform>
        </translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">Radius kleiner als 0.0 nach %1 konzentrischen Kreis(en).</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">Radius kleiner als 0.0 nach %1 konzentrischen Kreisbögen.</translation>
    </message>
</context>
</TS>
